/* 
 * File:   AnimatedImage.cpp
 * Author: MasterLinux
 * 
 * Created on 23. Juni 2010, 19:49
 */

#include "AnimatedImage.h"

AnimatedImage::AnimatedImage() {
    //init image
    this->initialize();
}

AnimatedImage::AnimatedImage(const char* _filePath) : Image(_filePath) {  
    //init image
    this->initialize();

    //add images to quene
}

AnimatedImage::AnimatedImage(const AnimatedImage& orig) : Image(orig) {
}

AnimatedImage::~AnimatedImage() {
    //clear all tiles in the list if exists
    if(!this->imageList->empty()) {
        this->imageList->clear();
    }
    //delete tilelist
    delete this->imageList;
}

void AnimatedImage::initialize() {
    //list of all images in the animation quene
    this->imageList = new vector<SDL_Surface*>();
    //declare vars
    this->isShuffled = false;
    this->isStarted = false;
    this->isReady = false;
    this->isPaused = false;
    this->pausedFrame = 0;
    this->startFrame = 0;
    this->timeFrame = 0;
    this->time = 0;
}

void AnimatedImage::addToQuene(const char* _filePath) {
    //add image to the quene
    this->imageList->push_back(Image::loadImage(_filePath));
    //set new time frame
    this->setAnimationTime(this->time);
}

void AnimatedImage::start() {
    this->startFrame = 0;
    
    //get start time
    this->animationStart = SDL_GetTicks();

    //start animation
    this->isStarted = true;
}

void AnimatedImage::start(int frame) {
    this->startFrame = frame;
    
    //get start time
    this->animationStart = SDL_GetTicks();

    //start animation
    this->isStarted = true;
}

void AnimatedImage::stop() {
    //reset start frame
    this->startFrame = 0;
    
    //stopAnimation
    this->isStarted = false;
    this->isReady = false;
}

void AnimatedImage::pause(bool p) {
    this->isPaused = p;
    
    if(p) {
        //save the current frame
        this->pausedFrame = this->currentFrame;
    } else {
        //start at a new start frame
        this->start(this->pausedFrame);
    }
}

void AnimatedImage::shuffle(bool s) {
    //set the shuffle-option
    this->isShuffled = s;

    //if the shuffle-option is enabled during the runtime reset the start timer
    if(s && this->isStarted) this->animationStart = SDL_GetTicks();
    if(!s) this->isReady = false;   
}

SDL_Surface* AnimatedImage::getImage(int frame) {
    return (*this->imageList)[frame];
}

SDL_Surface* AnimatedImage::getImage() {
    if(isStarted && !isPaused) {
        //animation duration
        Uint32 duration = SDL_GetTicks() - animationStart;
        //divide by 0
        if(this->timeFrame == 0) this->timeFrame = 1;
        //calculate current frame
        this->currentFrame  = (duration/this->timeFrame) + this->startFrame;
        Uint32 frame = this->currentFrame % this->imageList->size();

        //pause running at the last sdl_surface and return it
        if(!isShuffled) {
            //check if the animation is ended
            if(frame >= this->imageList->size()-1 && !isReady) {
                this->isReady = true;
            }
            //if animation ist ready, show only the last frame
            if(isReady) {
                return (*this->imageList)[this->imageList->size()-1];
            }
        }

        //return current sdl_surface
        return (*this->imageList)[frame];
        
    } else if (isStarted && isPaused) {
        //return paused image
        Uint32 frame = this->pausedFrame % this->imageList->size();
        return (*this->imageList)[frame];
    } else {
        //return first image
        return (*this->imageList)[this->startFrame];
    }
}

void AnimatedImage::setAnimationTime(int msec) {
    //save time
    this->time = msec;
    //divide by 0
    if(!this->imageList->empty()) {
        //how long will a frame showed
        this->timeFrame = floor(msec/this->imageList->size());
    }
}
