/* 
 * File:   AnimatedImage.h
 * Author: MasterLinux
 *
 * Created on 23. Juni 2010, 19:49
 */

#ifndef _ANIMATEDIMAGE_H
#define	_ANIMATEDIMAGE_H

#include "Image.h"
#include <cmath>
#include <vector>
#include "SDL.h"

class AnimatedImage : public Image {
public:
    /*
     * creates an animated image
     * animation-quene is empty
     */
    AnimatedImage();

    /*
     * creates an animated image
     *
     * supported formats:
     * - bmp
     * - gif
     * - tga
     *
     * @param filepath of an image
     */
    AnimatedImage(const char* _filePath);
    AnimatedImage(const AnimatedImage& orig);
    virtual ~AnimatedImage();

    /*
     * gets the current image in the animation-quene
     *
     * @return sdl image
     */
    SDL_Surface* getImage();

    /*
     * returns the image at the desired position in quene
     * info: quene starts at 0
     *
     * @param desired frame
     * @return sdl image
     */
    SDL_Surface* getImage(int frame);

    /*
     * adds an image to the animation-quene
     * 
     * supported formats:
     * - bmp
     * - gif
     * - tga
     *
     * @param filepath of the image
     */
    void addToQuene(const char* _filePath);

    /*
     * sets the time of animation
     * if 1000ms is set, the animation will run 1s
     *
     * @param runtime in milisecond
     */
    void setAnimationTime(int msec);

    /*
     * shuffle the animation
     * true -> the animation will run continuous
     * false -> the animation will run only one times
     *
     * @param boolean
     */
    void shuffle(bool s);

    /*
     * pause the animation
     * true -> the animation will stop
     * false -> it will run
     * 
     * @param boolean
     */
    void pause(bool p);

    /*
     * starts the animation
     * at the desired frame
     *
     * @param start frame
     */
    void start(int frame);

    /*
     * starts the animation
     * at the begin of the
     * animation-quene
     */
    void start();

    /*
     * stops the animation
     * if used, the first image in the
     * animation-quene will show
     */
    void stop();
      
private:
    vector<SDL_Surface*> *imageList;
    Uint32 currentFrame, pausedFrame, timeFrame, animationStart;
    bool isStarted, isShuffled, isReady, isPaused;
    int time, startFrame;

    /*
     * initialize something
     */
    void initialize();
};

#endif	/* _ANIMATEDIMAGE_H */

