/*
 * File:   Image.cpp
 * Author: MasterLinux
 *
 * Created on 12. Juni 2010, 14:50
 */

#include "Image.h"

Image::Image(const char* _filePath) {
    //get the image surface
    this->image = loadImage(_filePath);
    //delete the copy
    SDL_FreeSurface(this->surface);

    //get all info
    if(this->image) {
        //get image width and height
        setSize(this->image->w, this->image->h);
    } else {
        //set it to zero, if image couldn't load
        setSize(0, 0);
    }
    //sets position to zero
    setPosition(0, 0);
}

Image::Image() {}

Image::Image(const Image& orig) {
}

Image::~Image() {
    //delete the image surface
    SDL_FreeSurface(this->image);
}

SDL_Surface* Image::loadImage(const char* _filePath) {
    //create new string
    string path(_filePath);

    //create rwops structure
    SDL_RWops *rwop;
    rwop = SDL_RWFromFile(path.c_str(), "rw");

    if(IMG_isBMP(rwop)) {
        //load a bmp image
        if(!(surface = IMG_LoadBMP_RW(rwop))) {
            //show error
            std::cout << "BMP Image couldn't load" << std::endl;
            std::cout << "Error-Message: " << IMG_GetError() << std::endl;
        }
    } else if(IMG_isJPG(rwop)) {
        if(!(surface = IMG_LoadJPG_RW(rwop))){
            //show error
            std::cout << "JPG Image couldn't load" << std::endl;
            std::cout << "Error-Message: " << IMG_GetError() << std::endl;
        }
    } else if(path.find(".tga", 0) != string::npos) {
        if(!(surface = IMG_LoadTGA_RW(rwop))) {
            //show error
            std::cout << "TGA Image couldn't load" << std::endl;
            std::cout << "Error-Message: " << IMG_GetError() << std::endl;
        }
    } else {
        std::cout << "Error: Image has the wrong filetype!" << std::endl;
    }

    SDL_FreeRW(rwop);

    //conversion to screen format
    return surface;
}

void Image::setSize(int _width, int _height) {
    this->width = _width;
    this->height = _height;
}

void Image::getSize(int* _width, int* _height) {
    *_width = this->width;
    *_height = this->height;
}

void Image::setPosition(int _x, int _y) {
    this->x = _x;
    this->y = _y;
}

void Image::getPosition(int* _x, int* _y) {
    *_x = this->x;
    *_y = this->y;
}

SDL_Surface* Image::getImage() {
    return this->image;
}
