/*
 * File:   Image.h
 * Author: MasterLinux
 *
 * Created on 12. Juni 2010, 14:50
 */

#ifndef _IMAGE_H
#define	_IMAGE_H

#include "SDL.h"
#include "SDL_image.h"
#include <stdio.h>
#include <iostream>
#include <string>

using namespace std;

class Image {
public:
    /*
     * image object
     * loads an image and creates a SDL_Surface
     *
     * supported formats:
     * - bmp
     * - gif
     * - tga
     *
     * @param filepath of the image
     */
    Image(const char* _filePath);
    Image();
    Image(const Image& orig);
    virtual ~Image();

    /*
     * sets the position of this image
     * @param the position onto the x-axis
     * @param the position onto the y-axis
     */
    void setPosition(int _x, int _y);

    /*
     * gets the current position of this image
     * @param returns the current position onto the x-axis
     * @param returns the current position onto the y-axis
     */
    void getPosition(int* _x, int* _y);

    /*
     * gets the size of this image
     * @param returns the width
     * @param returns the height
     */
    void getSize(int* _width, int* _height);

    /*
     * returns the SDL_Surface of this image
     * @return SDL_Surface
     */
    SDL_Surface* getImage();

protected:
    /*
     * loads the image
     * and reads all necessary info about the image
     *
     * supported formats:
     * - bmp
     * - gif
     * - tga
     *
     * @param filepath of the image
     */
    SDL_Surface* loadImage(const char* _filePath);

    /*
     * sets the size of the image
     * @param width of the image
     * @param height of the image
     */
    void setSize(int _width, int _height);

private:
    int x, y;
    int width, height;
    const char *filePath;
    SDL_Surface *image, *surface;

};

#endif	/* _IMAGE_H */
